FakeStoreApi class
Constructors
- FakeStoreApi({ProductRepository? repository, CartRepository? cartRepository, UserRepository? userRepository})
Properties
- carts → CartApi
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- products → ProductApi
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- users → UserApi
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited