UserApi class

Constructors

UserApi({UserRepository? repository})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addUser(User user) → Future<Either<Failure, User>>
deleteUser(int id) → Future<Either<Failure, void>>
getAllUsers() → Future<Either<Failure, List<User>>>
getUserById(int id) → Future<Either<Failure, User>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateUser(UpdateUserParams updateProductParams) → Future<Either<Failure, User>>

Operators

operator ==(Object other) → bool
The equality operator.
inherited