Failure class

Constructors

Failure({required String title, required String code, required String description, required FailureSeverity type, required String stackTrace})
const
Failure.general({required String description, String stackTrace = ""})
factory
Failure.info({required String description, String stackTrace = ""})
factory
Failure.network({required String description, String stackTrace = ""})
factory
Failure.server({required String description, String stackTrace = ""})
factory

Properties

code → String
final
description → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → String
final
title → String
final
type → FailureSeverity
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited