CartGatewayImplementation class

Implemented types

Constructors

CartGatewayImplementation(DioClient _dioClient)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addCart(Map<String, dynamic> cart) Future<Either<Failure, Map<String, dynamic>>>
override
deleteCart(int id) Future<Either<Failure, void>>
override
getAllCarts() Future<Either<Failure, List<Map<String, dynamic>>>>
override
getCartById(int id) Future<Either<Failure, Map<String, dynamic>>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateCart(int id, Map<String, dynamic> cart) Future<Either<Failure, Map<String, dynamic>>>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited