ProductGatewayImplementation class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addNewProduct(Map<String, dynamic> product)
→ Future<Either<Failure, Map<String, dynamic>>>
-
override
-
deleteProduct(int id)
→ Future<Either<Failure, void>>
-
override
-
getAllProducts()
→ Future<Either<Failure, List<Map<String, dynamic>>>>
-
override
-
getProductById(int id)
→ Future<Either<Failure, Map<String, dynamic>>>
-
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
updateProduct(int id, Map<String, dynamic> product)
→ Future<Either<Failure, Map<String, dynamic>>>
-
override