UserRepositoryImpl class

Implemented types

Constructors

UserRepositoryImpl(UserGateway _gateway)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addUser(User user) Future<Either<Failure, User>>
override
deleteUser(int id) Future<Either<Failure, void>>
override
getAllUsers() Future<Either<Failure, List<User>>>
override
getUserById(int id) Future<Either<Failure, User>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateUser(int id, User user) Future<Either<Failure, User>>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited