User class

Implemented types

Constructors

User({required int id, required String username, required String password, required String phone})
User.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → int
final
password → String
final
phone → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
username → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited