UserGateway class abstract

Inheritance
Implementers

Constructors

UserGateway()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addUser(Map<String, dynamic> user) Future<Either<Failure, Map<String, dynamic>>>
deleteUser(int id) Future<Either<Failure, void>>
getAllUsers() Future<Either<Failure, List<Map<String, dynamic>>>>
getUserById(int id) Future<Either<Failure, Map<String, dynamic>>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateUser(int id, Map<String, dynamic> user) Future<Either<Failure, Map<String, dynamic>>>

Operators

operator ==(Object other) bool
The equality operator.
inherited