AddUser class

Implemented types

Constructors

AddUser(UserRepository repository)

Properties

hashCode → int
The hash code for this object.
no setterinherited
repository → UserRepository
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute(User user) → Future<Either<Failure, User>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited