CartApi class

Constructors

CartApi({CartRepository? repository})
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addCart(Cart cart) Future<Either<Failure, Cart>>
deleteCart(int id) Future<Either<Failure, void>>
getAllCarts() Future<Either<Failure, List<Cart>>>
getCartById(int id) Future<Either<Failure, Cart>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateCart(UpdateCartParams updateCartParams) Future<Either<Failure, Cart>>

Operators

operator ==(Object other) bool
The equality operator.
inherited