ProductApi class
Constructors
- ProductApi({ProductRepository? repository})
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addProduct(
Product product) → Future< Either< Failure, Product> > -
deleteProduct(
int id) → Future< Either< Failure, void> > -
getAllProducts(
) → Future< Either< Failure, List< >Product> > -
getProductById(
int id) → Future< Either< Failure, Product> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateProduct(
UpdateProductParams updateProductParams) → Future< Either< Failure, Product> >
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited