ProductModel class

Constructors

ProductModel({required int id, required String title, required double price, required String description, required String category, required String image})
const
ProductModel.fromJson(Map<String, dynamic> json)
factory

Properties

category String
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
id int
final
image String
final
price double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toEntity() Product
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited